


---

# foam_pet
Foam can interact with Aptos from an offline laptop.  


---

## Rules (License) 
This is a friendly pet.  
Please be friendly and festive with your pet and follow the rules.
Playing with, training, and cloning your pet is most likely 100% legit.  

### Cytes, Tissues, Organs
The aggregate of the licensing rules from Cytes, Tissues, Organs
laboratories can be found at "foam_pet/frontend_licenses.csv"

### Adoption Location
The adoption location has rules for pets in the "./[rules]" directory.  
At present, the rules are the "gpl-3.0-standalone License".   



---

## Adopt
```
pip install foam_pet
```

## Greet at a new habitat
```
foam_pet build
foam_pet demux_hap build_unverified_certificates
foam_pet ventures on
```

The pet is at:
[http://localhost:22000](http://localhost:22000)

******

## Docker
To adopting a pet that drives a docker vehicle,  
please check out:  
[https://github.com/basalt-plateau/foam-docker-images](https://github.com/basalt-plateau/foam-docker-images)  




